{% extends "admin/base.html" %}

{% block subtitle %}{{ _('Link availability') }}{% endblock %}




{% block secondary_content %}
    <div class="module module-narrow module-shallow">
        <h2 class="module-heading">
            <i class="fa fa-info-circle"></i>
            {{ _('Link availability') }}
        </h2>
        <div class="module-content">
            {% block admin_form_help %}
                {% block check_link_help_text %}
                {% endblock check_link_help_text %}
            {% endblock %}
        </div>
    </div>
{% endblock %}

{% block primary_content_inner %}
    {% block check_link_content %}
    {% endblock check_link_content %}
{% endblock primary_content_inner %}
